@@ -7,7 +7,7 @@
 * re-register components.
 *
 */
-#define NS_BUILD_ID 2005011221
+#define NS_BUILD_ID 2004080506
 
 /* GRE_BUILD_ID - GRE build version identifier
  *
@@ -17,7 +17,7 @@
  * GRE_BUILD_ID will just contain <milestone>. 
  *
  */
-#define GRE_BUILD_ID "1.8a6_2005011221"
+#define GRE_BUILD_ID "1.7.2_2004080506"
 
 #endif /* _NSBUILDID_H_ */
 
